@@ -32,6 +32,9 @@ class LineLengthTestCase(RuleTestCase):
         self.check('---\n' + 81 * 'a' + '\n', conf)
         self.check(1000 * 'b', conf)
         self.check('---\n' + 1000 * 'b' + '\n', conf)
+        self.check('content: |\n'
+                   '  {% this line is' + 99 * ' really' + ' long %}\n',
+                   conf)
 
     def test_default(self):
         conf = ('line-length: {max: 80}\n'
@@ -84,6 +87,9 @@ class LineLengthTestCase(RuleTestCase):
                    'another:\n'
                    '  - https://localhost/very/very/long/url\n'
                    '...\n', conf)
+        self.check('---\n'
+                   'long_line: http://localhost/very/very/long/url\n', conf,
+                   problem=(2, 21))
 
         conf = 'line-length: {max: 20, allow-non-breakable-words: no}'
         self.check('---\n' + 30 * 'A' + '\n', conf, problem=(2, 21))
@@ -106,3 +112,46 @@ class LineLengthTestCase(RuleTestCase):
                    'another:\n'
                    '  - https://localhost/very/very/long/url\n'
                    '...\n', conf, problem=(5, 21))
+        self.check('---\n'
+                   'long_line: http://localhost/very/very/long/url\n'
+                   '...\n', conf, problem=(2, 21))
+
+        conf = ('line-length: {max: 20, allow-non-breakable-words: yes}\n'
+                'trailing-spaces: disable')
+        self.check('---\n'
+                   'loooooooooong+word+and+some+space+at+the+end       \n',
+                   conf, problem=(2, 21))
+
+    def test_non_breakable_inline_mappings(self):
+        conf = 'line-length: {max: 20, ' \
+               'allow-non-breakable-inline-mappings: yes}'
+        self.check('---\n'
+                   'long_line: http://localhost/very/very/long/url\n'
+                   'long line: http://localhost/very/very/long/url\n', conf)
+        self.check('---\n'
+                   '- long line: http://localhost/very/very/long/url\n', conf)
+
+        self.check('---\n'
+                   'long_line: http://localhost/short/url + word\n'
+                   'long line: http://localhost/short/url + word\n',
+                   conf, problem1=(2, 21), problem2=(3, 21))
+
+        conf = ('line-length: {max: 20,'
+                '              allow-non-breakable-inline-mappings: yes}\n'
+                'trailing-spaces: disable')
+        self.check('---\n'
+                   'long_line: and+some+space+at+the+end       \n',
+                   conf, problem=(2, 21))
+        self.check('---\n'
+                   'long line: and+some+space+at+the+end       \n',
+                   conf, problem=(2, 21))
+        self.check('---\n'
+                   '- long line: and+some+space+at+the+end       \n',
+                   conf, problem=(2, 21))
+
+        # See https://github.com/adrienverge/yamllint/issues/21
+        conf = 'line-length: {allow-non-breakable-inline-mappings: yes}'
+        self.check('---\n'
+                   'content: |\n'
+                   '  {% this line is' + 99 * ' really' + ' long %}\n',
+                   conf, problem=(3, 81))
